@@ -21,7 +21,7 @@ class LoggedTask(Task):
         """
         Emit a log statement when the task is submitted.
         """
-        result = super(LoggedTask, self).apply_async(args=args, kwargs=kwargs, **options)
+        result = super().apply_async(args=args, kwargs=kwargs, **options)
         log.info('Task {}[{}] submitted with arguments {}, {}'.format(
             self.name,
             result.id,
@@ -34,7 +34,7 @@ class LoggedTask(Task):
         """
         Capture the exception that caused the task to be retried, if any.
         """
-        super(LoggedTask, self).on_retry(exc, task_id, args, kwargs, einfo)
+        super().on_retry(exc, task_id, args, kwargs, einfo)
         log.warning('[{}] retried due to {}'.format(task_id, getattr(einfo, 'traceback', None)))
 
     def on_failure(self, exc, task_id, args, kwargs, einfo):
@@ -42,4 +42,4 @@ class LoggedTask(Task):
         Capture the exception that caused the task to fail, if any.
         """
         log.error('[{}] failed due to {}'.format(task_id, getattr(einfo, 'traceback', None)))
-        super(LoggedTask, self).on_failure(exc, task_id, args, kwargs, einfo)
+        super().on_failure(exc, task_id, args, kwargs, einfo)
